@@ -255,6 +255,11 @@ ggplot2::ggplot(data=dta, ggplot2::aes(x=x,y=y,col=Tests))+
   ggplot2::labs(x="p value", y="CDF")+
   ggplot2::scale_color_manual(values=c("blue","red", "Orange", "green"))
 
+## -----------------------------------------------------------------------------
+x=rnull()
+Rgof::gof_test_adjusted_pvalue(x, NA, pnull, rnull, 
+              B=c(100, 100), maxProcessor = 1)
+
 ## -----------------------------------------------------------------------------
 df=3
 pnull=function(x) pnorm(x)/(2*pnorm(3)-1)
